#ifndef GDHCPD_populate_ranges_H
#   define GDHCPD_populate_ranges_H

extern struct w *widgets;

void populate_ranges(struct w *widgets, 
                                    	    gchar *nic, 
                                            gchar *subnet, 
					    gchar *netmask);

#endif
